@@ -112,6 +112,18 @@ def _standard_pythonizations(pyclass, name):
                 return res
             raise IndexError(idx)
         pyclass.__getitem__ = tuple_getitem
+
+  # pythoniztion of std::string; placed here because it's simpler to write the
+  # custom "npos" object (to allow easy result checking of find/rfind) in Python
+    elif pyclass.__cpp_name__ == "std::string":
+        class NPOS(0x3000000 <= sys.hexversion and int or long):
+            def __eq__(self, other):
+                return other == -1 or  int(self) == other
+            def __ne__(self, other):
+                return other != -1 and int(self) != other
+        del pyclass.__class__.npos          # drop b/c is const data
+        pyclass.npos = NPOS(pyclass.npos)
+
     return True
 
 if not ispypy:
@@ -280,6 +292,8 @@ if not ispypy:
         else:
             add_include_path(apipath_extra)
 
+    del apipath_extra
+
 if os.getenv('CONDA_PREFIX'):
   # MacOS, Linux
     include_path = os.path.join(os.getenv('CONDA_PREFIX'), 'include')
